cHaversine
==========

Fast haversine calculation. Returns distance between two lat/lon pairs in
meters. Implemented using Cython.

Usage
-----

    >>> from cHaversine import haversine

    >>> haversine((39.7683331, -86.1583502), (39.16534, -86.52352))

    73968.34251401595
